nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Endptctrl1

Struct Endptctrl1 

#[repr(transparent)]
pub struct Endptctrl1(pub u32);
Endpoint Control 1

Tuple Fields

0: u32

Implementations

Source

impl Endptctrl1

pub const fn rxs(&self) -> bool

RX Endpoint Stall - Read/Write 0 End Point OK

pub const fn set_rxs(&mut self, val: bool)

RX Endpoint Stall - Read/Write 0 End Point OK

pub const fn rxd(&self) -> bool

RX Endpoint Data Sink - Read/Write 0 Dual Port Memory Buffer/DMA Engine [Default] Should always be written as zero

pub const fn set_rxd(&mut self, val: bool)

RX Endpoint Data Sink - Read/Write 0 Dual Port Memory Buffer/DMA Engine [Default] Should always be written as zero

pub const fn rxt(&self) -> u8

RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt

pub const fn set_rxt(&mut self, val: u8)

RX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt

pub const fn rxi(&self) -> bool

RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used for test and should always be written as zero

pub const fn set_rxi(&mut self, val: bool)

RX Data Toggle Inhibit 0 Disabled [Default] 1 Enabled This bit is only used for test and should always be written as zero

pub const fn rxr(&self) -> bool

RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a configuration event is received for this Endpoint, software must write a one to this bit in order to synchronize the data PID’s between the host and device

pub const fn set_rxr(&mut self, val: bool)

RX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a configuration event is received for this Endpoint, software must write a one to this bit in order to synchronize the data PID’s between the host and device

pub const fn rxe(&self) -> bool

RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be enabled only after it has been configured

pub const fn set_rxe(&mut self, val: bool)

RX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be enabled only after it has been configured

pub const fn txs(&self) -> bool

TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit will be cleared automatically upon receipt of a SETUP request if this Endpoint is configured as a Control Endpoint and this bit will continue to be cleared by hardware until the associated ENDPTSETUPSTAT bit is cleared

pub const fn set_txs(&mut self, val: bool)

TX Endpoint Stall - Read/Write 0 End Point OK 1 End Point Stalled This bit will be cleared automatically upon receipt of a SETUP request if this Endpoint is configured as a Control Endpoint and this bit will continue to be cleared by hardware until the associated ENDPTSETUPSTAT bit is cleared

pub const fn txd(&self) -> bool

TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine [DEFAULT] Should always be written as 0

pub const fn set_txd(&mut self, val: bool)

TX Endpoint Data Source - Read/Write 0 Dual Port Memory Buffer/DMA Engine [DEFAULT] Should always be written as 0

pub const fn txt(&self) -> u8

TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt

pub const fn set_txt(&mut self, val: u8)

TX Endpoint Type - Read/Write 00 Control 01 Isochronous 10 Bulk 11 Interrupt

pub const fn txi(&self) -> bool

TX Data Toggle Inhibit 0 PID Sequencing Enabled

pub const fn set_txi(&mut self, val: bool)

TX Data Toggle Inhibit 0 PID Sequencing Enabled

pub const fn txr(&self) -> bool

TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a configuration event is received for this Endpoint, software must write a one to this bit in order to synchronize the data PID’s between the Host and device

pub const fn set_txr(&mut self, val: bool)

TX Data Toggle Reset (WS) Write 1 - Reset PID Sequence Whenever a configuration event is received for this Endpoint, software must write a one to this bit in order to synchronize the data PID’s between the Host and device

pub const fn txe(&self) -> bool

TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be enabled only after it has been configured

pub const fn set_txe(&mut self, val: bool)

TX Endpoint Enable 0 Disabled [Default] 1 Enabled An Endpoint should be enabled only after it has been configured