#[repr(transparent)]pub struct Gptimer0ctrl(pub u32);Expand description
General Purpose Timer #0 Controller
Tuple Fields
0: u32Implementations
Sourceimpl Gptimer0ctrl
impl Gptimer0ctrl
Sourcepub const fn gptcnt(&self) -> u32
pub const fn gptcnt(&self) -> u32
General Purpose Timer Counter. This field is the count value of the countdown timer.
Sourcepub const fn set_gptcnt(&mut self, val: u32)
pub const fn set_gptcnt(&mut self, val: u32)
General Purpose Timer Counter. This field is the count value of the countdown timer.
Sourcepub const fn gptmode(&self) -> Gptimer0ctrlGptmode
pub const fn gptmode(&self) -> Gptimer0ctrlGptmode
General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software; In repeat mode, the timer will count down to zero, generate an interrupt and automatically reload the counter value from GPTLD bits to start again
Sourcepub const fn set_gptmode(&mut self, val: Gptimer0ctrlGptmode)
pub const fn set_gptmode(&mut self, val: Gptimer0ctrlGptmode)
General Purpose Timer Mode In one shot mode, the timer will count down to zero, generate an interrupt, and stop until the counter is reset by software; In repeat mode, the timer will count down to zero, generate an interrupt and automatically reload the counter value from GPTLD bits to start again
Sourcepub const fn gptrst(&self) -> Gptimer0ctrlGptrst
pub const fn gptrst(&self) -> Gptimer0ctrlGptrst
General Purpose Timer Reset
Sourcepub const fn set_gptrst(&mut self, val: Gptimer0ctrlGptrst)
pub const fn set_gptrst(&mut self, val: Gptimer0ctrlGptrst)
General Purpose Timer Reset
Sourcepub const fn gptrun(&self) -> Gptimer0ctrlGptrun
pub const fn gptrun(&self) -> Gptimer0ctrlGptrun
General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.
Sourcepub const fn set_gptrun(&mut self, val: Gptimer0ctrlGptrun)
pub const fn set_gptrun(&mut self, val: Gptimer0ctrlGptrun)
General Purpose Timer Run GPTCNT bits are not effected when setting or clearing this bit.