nxp-pac

Crates

git

Versions

mimxrt1011

Flavors

Hwgeneral

Struct Hwgeneral 

#[repr(transparent)]
pub struct Hwgeneral(pub u32);
Hardware General

Tuple Fields

0: u32

Implementations

Source

impl Hwgeneral

pub const fn phyw(&self) -> Phyw

Data width of the transciever connected to the controller core. PHYW bit reset value is

pub const fn set_phyw(&mut self, val: Phyw)

Data width of the transciever connected to the controller core. PHYW bit reset value is

pub const fn phym(&self) -> Phym

Transciever type

pub const fn set_phym(&mut self, val: Phym)

Transciever type

pub const fn sm(&self) -> Sm

Serial interface mode capability

pub const fn set_sm(&mut self, val: Sm)

Serial interface mode capability